@@ -23,76 +23,49 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-"""
-Rect class is an internal data structure allowing to manipulate rectangle shapes
-"""
-
 
 from typing import NamedTuple
 import dlib
 
 class Rect(NamedTuple):
-    x1 : float # left
-    y1 : float # top
-    x2 : float # right
-    y2 : float # bottom
+    """
+    This class is an internal data structure allowing to manipulate rectangle shapes
+    """
+
+    #: left
+    x1 : float
+    #: top
+    y1 : float
+    #: right
+    x2 : float
+    #: bottom
+    y2 : float
+
     @property
     def w(self):
-        """ returns Rect width """
+        """ self width """
         return self.x2 - self.x1
+
     @property
     def h(self):
-        """ returns Rect height """
+        """ self height """
         return self.y2 - self.y1
+
     @property
     def center(self):
-        """ returns center (x,y) of Rect (x1, y1, x2, y2) """
+        """ center (x,y) of self (x1, y1, x2, y2) """
         x1, y1, x2, y2 = self
         return ((x1 + x2) / 2), ((y1 + y2) / 2)
+
     @property
     def area(self):
+        """ self Surface area """
         return self.w * self.h
+
     @property
     def max_dim_len(self):
-        """ Return max of Rect width and height """
+        """ max (width, height)"""
         return max(self.h, self.w)
-    def transpose(self, x, y):
-        """ Returns a transposed Rect"""
-        x1, y1, x2, y2 = self
-        return Rect(x1 + x, y1 + y, x2 + x, y2 + y)
-    def mult(self, x, y):
-        x1, y1, x2, y2 = self
-        return Rect(x1 * x, y1 * y, x2 * x, y2 * y)
-
-    def intersect(self, r):
-        x1, y1, x2, y2 = self
-        ret = Rect(max(x1, r.x1), max(y1, r.y1), min(x2, r.x2), min(y2, r.y2))
-        if ret.h <= 0 or ret.w <= 0:
-            return Rect(0,0,0,0)
-        return ret
-
-    def iou(self, r):
-        inter = self.intersect(r).area
-        union = self.area + r.area - inter
-        return inter / union
-
-    def __contains__(self, point):
-        x1, y1, x2, y2 = self
-        x, y = point
-        return x >= x1 and x <= x2 and y >= y1 and y <= y2
-
-    def to_int(self):
-        return Rect(*[int(round(e)) for e in self])
-
-    @staticmethod
-    def from_dlib(x):
-        return Rect(x.left(), x.top(), x.right(), x.bottom())
-
-    def to_dlibInt(self):
-        return dlib.rectangle(*[e for e in self.to_int()])
-
-    def to_dlibFloat(self):
-        return dlib.drectangle(*self)
 
     @property
     def square(self):
@@ -101,8 +74,139 @@ class Rect(NamedTuple):
         xc, yc = self.center
         return Rect(xc - offset, yc - offset, xc + offset, yc + offset)
 
+
+    def transpose(self, xoffset, yoffset):
+        """
+        Translation
+
+        Args:
+            xoffset (float): horizontal offset.
+            yoffset (float): vertical offset.
+        Returns:
+            Rect :
+        """
+        x1, y1, x2, y2 = self
+        return Rect(x1 + xoffset, y1 + yoffset, x2 + xoffset, y2 + yoffset)
+
+    def mult(self, x, y):
+        """
+        Multiply self coordinates by horizontal and vertical scaling factors
+        Usefull for converting [0...1] coordinates to image frame dimensions in pixels
+
+        Args:
+            x (float: horizontal scaling factor.
+            y (float): vertical scaling factor.
+
+        Returns:
+            Rect:
+
+        """
+        x1, y1, x2, y2 = self
+        return Rect(x1 * x, y1 * y, x2 * x, y2 * y)
+
+    def intersect(self, r):
+        """
+        Rectangle intersection between self and r
+
+        Args:
+            r (Rect):
+
+        Returns:
+            Rect:
+
+        """
+        x1, y1, x2, y2 = self
+        ret = Rect(max(x1, r.x1), max(y1, r.y1), min(x2, r.x2), min(y2, r.y2))
+        if ret.h <= 0 or ret.w <= 0:
+            return Rect(0,0,0,0)
+        return ret
+
+    def iou(self, r):
+        """
+        Intersection Over Union between self and r
+
+        Args:
+            r (Rect):
+
+        Returns:
+            float:
+
+        """
+        inter = self.intersect(r).area
+        union = self.area + r.area - inter
+        return inter / union
+
+    def __contains__(self, point):
+        """
+        point contained in self
+
+        Args:
+            point (tuple): (x,y)
+
+        Returns:
+            bool: True if point is in self, else False
+
+        """
+
+        x1, y1, x2, y2 = self
+        x, y = point
+        return x >= x1 and x <= x2 and y >= y1 and y <= y2
+
+    def to_int(self):
+        """
+        Convert self coordinates (float) to the nearest int values
+        Returns:
+            Rect:
+        """
+        return Rect(*[int(round(e)) for e in self])
+
+    @staticmethod
+    def from_dlib(x):
+        """
+        create Rect from dlib's rectangle instance
+
+        Args:
+            x (dlib.rectangle or dlib.drectangle):
+
+        Returns:
+            Rect:
+
+        """
+        return Rect(x.left(), x.top(), x.right(), x.bottom())
+
+
+    def to_dlibInt(self):
+        """
+        Convert self to dlib.rectangle (int)
+
+        Returns:
+            dlib.rectangle:
+
+        """
+        return dlib.rectangle(*[e for e in self.to_int()])
+
+    def to_dlibFloat(self):
+        """
+        Convert self to dlib.drectangle (float)
+
+        Returns:
+            dlib.drectangle:
+
+        """
+        return dlib.drectangle(*self)
+
+
     def scale(self, scale_prct):
-        """ scale Rectangle according to scale percentage scale_prct"""
+        """
+        scale self according to a given scale percentage
+
+        Args:
+            scale_prct (float):
+
+        Returns:
+            Rect:
+
+        """
         w, h = (self.w, self.h)
         x1, y1, x2, y2 = self
         xdiff = (w * scale_prct - w) / 2
